=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2005-11-30 14:55:03 +0000
+++ bzrlib/builtins.py	2005-11-30 15:15:17 +0000
@@ -395,7 +395,7 @@
                                   "  Try merge.")
         if br_to.get_parent() is None or remember:
             br_to.set_parent(location)
-        note('%d revision(s) pulled.', count)
+        note('%d revision(s) pulled.' % (count,))
 
         if verbose:
             new_rh = tree_to.branch.revision_history()
@@ -1273,7 +1273,7 @@
             raise BzrCommandError("Commit refused because there are unknown "
                                   "files in the working tree.")
         note('Committed revision %d.' % (tree.branch.revno(),))
-        
+
 
 class cmd_check(Command):
     """Validate consistency of branch history.

=== modified file 'bzrlib/tests/test_http.py'
--- bzrlib/tests/test_http.py	2005-11-23 15:44:24 +0000
+++ bzrlib/tests/test_http.py	2005-11-30 15:15:17 +0000
@@ -1,9 +1,27 @@
 # (C) 2005 Canonical
 
 from bzrlib.tests import TestCase
-from bzrlib.transport.http import HttpTransport
-
+from bzrlib.transport.http import HttpTransport, extract_auth
+
+class FakeManager (object):
+    def __init__(self):
+        self.credentials = []
+        
+    def add_password(self, realm, host, username, password):
+        self.credentials.append([realm, host, username, password])
+
+        
 class TestHttpUrls(TestCase):
+    def test_url_parsing(self):
+        f = FakeManager()
+        url = extract_auth('http://example.com', f)
+        self.assertEquals('http://example.com', url)
+        self.assertEquals(0, len(f.credentials))
+        url = extract_auth('http://user:pass@www.bazaar-ng.org/bzr/bzr.dev', f)
+        self.assertEquals('http://www.bazaar-ng.org/bzr/bzr.dev', url)
+        self.assertEquals(1, len(f.credentials))
+        self.assertEquals([None, 'www.bazaar-ng.org', 'user', 'pass'], f.credentials[0])
+        
     def test_abs_url(self):
         """Construction of absolute http URLs"""
         t = HttpTransport('http://bazaar-ng.org/bzr/bzr.dev/')

=== modified file 'bzrlib/trace.py'
--- bzrlib/trace.py	2005-11-30 14:55:03 +0000
+++ bzrlib/trace.py	2005-11-30 15:15:17 +0000
@@ -54,6 +54,7 @@
 _trace_file = None
 _bzr_log_file = None
 
+
 class QuietFormatter(logging.Formatter):
     """Formatter that supresses the details of errors.
 

=== modified file 'bzrlib/transport/http.py'
--- bzrlib/transport/http.py	2005-11-23 06:25:50 +0000
+++ bzrlib/transport/http.py	2005-11-30 15:15:17 +0000
@@ -21,7 +21,7 @@
                            NonRelativePath, TransportError, ConnectionError)
 import os, errno
 from cStringIO import StringIO
-import urllib2
+import urllib, urllib2
 import urlparse
 
 from bzrlib.errors import BzrError, BzrCheckError
@@ -29,10 +29,45 @@
 from bzrlib.trace import mutter
 
 
+def extract_auth(url, password_manager):
+    """
+    Extract auth parameters from am HTTP/HTTPS url and add them to the given
+    password manager.  Return the url, minus those auth parameters (which
+    confuse urllib2).
+    """
+    assert url.startswith('http://') or url.startswith('https://')
+    scheme, host = url.split('//', 1)
+    if '/' in host:
+        host, path = host.split('/', 1)
+        path = '/' + path
+    else:
+        path = ''
+    port = ''
+    if '@' in host:
+        auth, host = host.split('@', 1)
+        if ':' in auth:
+            username, password = auth.split(':', 1)
+        else:
+            username, password = auth, None
+        if ':' in host:
+            host, port = host.split(':', 1)
+            port = ':' + port
+        # FIXME: if password isn't given, should we ask for it?
+        if password is not None:
+            username = urllib.unquote(username)
+            password = urllib.unquote(password)
+            password_manager.add_password(None, host, username, password)
+    url = scheme + '//' + host + port + path
+    return url
+    
 def get_url(url):
     import urllib2
-    mutter("get_url %s", url)
-    url_f = urllib2.urlopen(url)
+    mutter("get_url %s" % url)
+    manager = urllib2.HTTPPasswordMgrWithDefaultRealm()
+    url = extract_auth(url, manager)
+    auth_handler = urllib2.HTTPBasicAuthHandler(manager)
+    opener = urllib2.build_opener(auth_handler)
+    url_f = opener.open(url)
     return url_f
 
 class HttpTransportError(TransportError):

